@@ -11,6 +11,7 @@ from pipeline.compressors.yui import YUICompressor
 
 class CompressorTest(TestCase):
     def setUp(self):
+        self.maxDiff = None
         self.compressor = Compressor()
 
     def test_js_compressor_class(self):
@@ -21,24 +22,24 @@ class CompressorTest(TestCase):
 
     def test_concatenate_and_rewrite(self):
         css = self.compressor.concatenate_and_rewrite([
-            'css/first.css',
-            'css/second.css'
+            'pipeline/css/first.css',
+            'pipeline/css/second.css'
         ], 'css/screen.css')
         self.assertEquals(""".concat {\n  display: none;\n}\n\n.concatenate {\n  display: block;\n}\n""", css)
 
     def test_concatenate(self):
         js = self.compressor.concatenate([
-            'js/first.js',
-            'js/second.js'
+            'pipeline/js/first.js',
+            'pipeline/js/second.js'
         ])
         self.assertEquals("""function concat() {\n  console.log(arguments);\n}\n\nfunction cat() {\n  console.log("hello world");\n}\n""", js)
 
     @patch.object(base64, 'b64encode')
     def test_encoded_content(self, mock):
-        self.compressor.encoded_content('images/arrow.png')
+        self.compressor.encoded_content('pipeline/images/arrow.png')
         self.assertTrue(mock.called)
         mock.reset_mock()
-        self.compressor.encoded_content('images/arrow.png')
+        self.compressor.encoded_content('pipeline/images/arrow.png')
         self.assertFalse(mock.called)
 
     def test_relative_path(self):
@@ -70,19 +71,19 @@ class CompressorTest(TestCase):
         self.assertEquals(name, 'photo_detail')
 
     def test_compile_templates(self):
-        templates = self.compressor.compile_templates(['templates/photo/list.jst'])
+        templates = self.compressor.compile_templates(['pipeline/templates/photo/list.jst'])
         self.assertEquals(templates, """window.JST = window.JST || {};\n%s\nwindow.JST[\'list\'] = template(\'<div class="photo">\\n <img src="<%%= src %%>" />\\n <div class="caption">\\n  <%%= caption %%>\\n </div>\\n</div>\');\n""" % TEMPLATE_FUNC)
         templates = self.compressor.compile_templates([
-            'templates/video/detail.jst',
-            'templates/photo/detail.jst'
+            'pipeline/templates/video/detail.jst',
+            'pipeline/templates/photo/detail.jst'
         ])
         self.assertEqual(templates, """window.JST = window.JST || {};\n%s\nwindow.JST[\'video_detail\'] = template(\'<div class="video">\\n <video src="<%%= src %%>" />\\n <div class="caption">\\n  <%%= description %%>\\n </div>\\n</div>\');\nwindow.JST[\'photo_detail\'] = template(\'<div class="photo">\\n <img src="<%%= src %%>" />\\n <div class="caption">\\n  <%%= caption %%> by <%%= author %%>\\n </div>\\n</div>\');\n""" % TEMPLATE_FUNC)
 
     def test_embeddable(self):
-        self.assertFalse(self.compressor.embeddable('images/sprite.png', None))
-        self.assertFalse(self.compressor.embeddable('images/arrow.png', 'datauri'))
-        self.assertTrue(self.compressor.embeddable('images/embed/arrow.png', 'datauri'))
-        self.assertFalse(self.compressor.embeddable('images/arrow.dat', 'datauri'))
+        self.assertFalse(self.compressor.embeddable('pipeline/images/sprite.png', None))
+        self.assertFalse(self.compressor.embeddable('pipeline/images/arrow.png', 'datauri'))
+        self.assertTrue(self.compressor.embeddable('pipeline/images/embed/arrow.png', 'datauri'))
+        self.assertFalse(self.compressor.embeddable('pipeline/images/arrow.dat', 'datauri'))
 
     def test_construct_asset_path(self):
         asset_path = self.compressor.construct_asset_path("../../images/sprite.png",
@@ -94,18 +95,18 @@ class CompressorTest(TestCase):
 
     def test_url_rewrite(self):
         output = self.compressor.concatenate_and_rewrite([
-            'css/urls.css',
+            'pipeline/css/urls.css',
         ], 'css/screen.css')
         self.assertEquals(u"""@font-face {
   font-family: 'Pipeline';
-  src: url(../fonts/pipeline.eot);
-  src: url(../fonts/pipeline.eot?#iefix) format('embedded-opentype');
-  src: local('☺'), url(../fonts/pipeline.woff) format('woff'), url(../fonts/pipeline.ttf) format('truetype'), url(../fonts/pipeline.svg#IyfZbseF) format('svg');
+  src: url(../pipeline/fonts/pipeline.eot);
+  src: url(../pipeline/fonts/pipeline.eot?#iefix) format('embedded-opentype');
+  src: local('☺'), url(../pipeline/fonts/pipeline.woff) format('woff'), url(../pipeline/fonts/pipeline.ttf) format('truetype'), url(../pipeline/fonts/pipeline.svg#IyfZbseF) format('svg');
   font-weight: normal;
   font-style: normal;
 }
 .relative-url {
-  background-image: url(../images/sprite-buttons.png);
+  background-image: url(../pipeline/images/sprite-buttons.png);
 }
 .absolute-url {
   background-image: url(/images/sprite-buttons.png);
